@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 
-# Copyright 2013-2014 The Meson development team
+# Copyright 2013-2016 The Meson development team
 
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -23,7 +23,7 @@ Not part of the main test suite because of two reasons:
 Eventually migrate to something fancier.'''
 
 import os, subprocess, shutil, sys
-import environment
+import mesonbuild.environment as environment
 
 from run_tests import gather_tests
 
